@@ -15,7 +15,7 @@ from botocore.exceptions import (
 from rich.progress import track
 
 from ..model import RESOURCE_TYPES, aws
-from ..model.entity import EntityAttrs, EntityState, EntityType, EntityUpdate
+from ..model.entity import EntityAttrs, EntityState, EntityT, EntityUpdate
 from .abstract import AbstractSource
 
 log = logging.getLogger(__name__)
@@ -39,7 +39,7 @@ class AWSSource(AbstractSource):
     def update(
         self,
         resource_types: Optional[List[str]] = None,
-        active_resources: Optional[List[EntityType]] = None,
+        active_resources: Optional[List[EntityT]] = None,
     ) -> List[EntityUpdate]:
         """Get the latest state of the source entities.
 
@@ -91,7 +91,7 @@ class AWSSource(AbstractSource):
         for entity in remaining_entities:
             if type(entity) in resource_models:
                 log.info(
-                    f"Marking '{entity._model_name}' with id '{entity.id_}' and name "
+                    f"Marking '{entity.model_name}' with id '{entity.id_}' and name "
                     f"'{entity.name}' as terminated"
                 )
                 entity.state = EntityState.TERMINATED
@@ -101,7 +101,7 @@ class AWSSource(AbstractSource):
 
         return entity_updates
 
-    def _update_ec2(self, remaining_entities: List[EntityType]) -> List[EntityUpdate]:
+    def _update_ec2(self, remaining_entities: List[EntityT]) -> List[EntityUpdate]:
         """Fetch the data of the EC2 instances.
 
         Args:
@@ -183,7 +183,7 @@ class AWSSource(AbstractSource):
                 )
         return entity_updates
 
-    def _update_rds(self, remaining_entities: List[EntityType]) -> List[EntityUpdate]:
+    def _update_rds(self, remaining_entities: List[EntityT]) -> List[EntityUpdate]:
         """Fetch the data of the RDS instances.
 
         Args:
@@ -253,7 +253,7 @@ class AWSSource(AbstractSource):
         return entity_updates
 
     @classmethod
-    def _update_s3(cls, remaining_entities: List[EntityType]) -> List[EntityUpdate]:
+    def _update_s3(cls, remaining_entities: List[EntityT]) -> List[EntityUpdate]:
         """Fetch the data of the S3 buckets.
 
         Args:
@@ -287,11 +287,18 @@ class AWSSource(AbstractSource):
                         grant["Grantee"]["URI"]
                         == "http://acs.amazonaws.com/groups/global/AllUsers"
                     ):
-                        for permission in grant["Permission"]:
-                            if permission.text == "READ":
+                        permissions = grant["Permission"]
+                        if isinstance(permissions, str):
+                            permissions = [permissions]
+                        for permission in permissions:
+                            if permission == "READ":
                                 entity_data["public_read"] = True
-                            elif permission.text == "WRITE":
+                            elif permission == "WRITE":
                                 entity_data["public_write"] = True
+                            elif permission == "READ_ACP":
+                                entity_data["public_read"] = False
+                            elif permission == "WRITE_ACP":
+                                entity_data["public_write"] = False
 
             # ignore: I don't know why it's not able to infer the type of the
             # argument 1 of _build_entity_update ¯\(°_o)/¯
@@ -304,9 +311,7 @@ class AWSSource(AbstractSource):
         return entity_updates
 
     @classmethod
-    def _update_route53(
-        cls, remaining_entities: List[EntityType]
-    ) -> List[EntityUpdate]:
+    def _update_route53(cls, remaining_entities: List[EntityT]) -> List[EntityUpdate]:
         """Fetch the data of the Route53 records.
 
         Args:
@@ -340,19 +345,17 @@ class AWSSource(AbstractSource):
                 instances += records["ResourceRecordSets"]
 
             for instance in instances:
+                hosted_zone_id = re.sub(r"/hostedzone/", "", hosted_zone["Id"])
+                name = re.sub(r"\.$", "", instance["Name"])
                 entity_data = {
-                    "hosted_zone": re.sub(r"/hostedzone/", "", hosted_zone["Id"]),
-                    "name": re.sub(r"\.$", "", instance["Name"]),
+                    "id_": f"{hosted_zone_id}-{name}-{instance['Type'].lower()}",
+                    "hosted_zone": hosted_zone_id,
+                    "name": name,
                     "type_": instance["Type"],
                     "state": "active",
                     "public": not hosted_zone["Config"]["PrivateZone"],
                 }
 
-                entity_data["id_"] = (
-                    f"{entity_data['hosted_zone']}-"
-                    f"{entity_data['name']}-{entity_data['type_'].lower()}"
-                )
-
                 try:
                     entity_data["values"] = [
                         record["Value"] for record in instance["ResourceRecords"]
@@ -369,7 +372,7 @@ class AWSSource(AbstractSource):
                 )
         return entity_updates
 
-    def _update_vpc(self, remaining_entities: List[EntityType]) -> List[EntityUpdate]:
+    def _update_vpc(self, remaining_entities: List[EntityT]) -> List[EntityUpdate]:
         """Fetch the data of the VPC resources.
 
         Args:
@@ -420,7 +423,7 @@ class AWSSource(AbstractSource):
                 )
         return entity_updates
 
-    def _update_asg(self, remaining_entities: List[EntityType]) -> List[EntityUpdate]:
+    def _update_asg(self, remaining_entities: List[EntityT]) -> List[EntityUpdate]:
         """Fetch the data of the ASG resources.
 
         Args:
@@ -482,7 +485,7 @@ class AWSSource(AbstractSource):
 
         return entity_updates
 
-    def _update_sg(self, remaining_entities: List[EntityType]) -> List[EntityUpdate]:
+    def _update_sg(self, remaining_entities: List[EntityT]) -> List[EntityUpdate]:
         """Fetch the data of the Security Group resources.
 
         Args:
@@ -529,9 +532,7 @@ class AWSSource(AbstractSource):
         return entity_updates
 
     @classmethod
-    def _update_iam_users(
-        cls, remaining_entities: List[EntityType]
-    ) -> List[EntityUpdate]:
+    def _update_iam_users(cls, remaining_entities: List[EntityT]) -> List[EntityUpdate]:
         """Fetch the data of the IAM users.
 
         Args:
@@ -566,7 +567,7 @@ class AWSSource(AbstractSource):
 
     @classmethod
     def _update_iam_groups(
-        cls, remaining_entities: List[EntityType]
+        cls, remaining_entities: List[EntityT]
     ) -> List[EntityUpdate]:
         """Fetch the data of the IAM groups.
 
@@ -652,8 +653,8 @@ def build_security_group_rule_data(rule_data: Dict[str, Any]) -> Dict[str, Any]:
 
 def _build_entity_update(
     entity_data: EntityAttrs,
-    entity_model: Type[EntityType],
-    remaining_entities: List[EntityType],
+    entity_model: Type[EntityT],
+    remaining_entities: List[EntityT],
 ) -> EntityUpdate:
     """Create the EntityUpdate object from the entity_data and model.
 
