@@ -39,7 +39,7 @@ def cli(ctx: Context, config_path: str, verbose: bool) -> None:
     load_logger(verbose)
     config = load_config(config_path)
     ctx.obj["config"] = config
-    ctx.obj["repo"] = load_repository(config.database_url, search_exception=False)
+    ctx.obj["repo"] = load_repository(config.database_url)
     ctx.obj["adapters"] = load_adapters(config)
     ctx.obj["prompter"] = PydanticQuestions()
 
@@ -169,7 +169,7 @@ def unused(
 @click.pass_context
 @click.argument(
     "resource_type",
-    type=click.Choice(["pro", "ser", "per", "inf"]),
+    type=click.Choice(["pro", "ser", "per", "inf", "auth", "net", "risk", "sec"]),
 )
 def add(ctx: Context, resource_type: str) -> None:
     """Add resources."""
@@ -188,6 +188,19 @@ def add(ctx: Context, resource_type: str) -> None:
     services.add(repo, resource)
 
 
+@cli.command(name="risk")
+@click.pass_context
+def risk(
+    ctx: Context,
+) -> None:
+    """Show an ordered list of services by the security value."""
+    services_ = services.service_risk(ctx.obj["repo"])
+    accesses = services.accesses(ctx.obj["repo"])
+    ctx.obj["repo"].close()
+
+    views.service_risk(services_, accesses)
+
+
 @cli.command(hidden=True)
 def null() -> None:
     """Do nothing.
